@@ -7,8 +7,8 @@ from warnings import warn
 import napari
 
 import pyclesperanto_prototype as cle
-from qtpy.QtWidgets import QFileDialog, QLineEdit, QVBoxLayout, QWidget, QMenu
-from qtpy.QtGui import QCursor
+from qtpy.QtWidgets import QFileDialog, QLineEdit, QVBoxLayout, QHBoxLayout, QWidget, QMenu, QLabel
+from qtpy.QtGui import QCursor, QIcon
 
 from typing import Union
 
@@ -86,6 +86,7 @@ class Assistant(QWidget):
             ("Export Python script to file", self.to_jython),
             ("Export Jupyter Notebook", self.to_notebook),
             ("Copy to clipboard", self.to_clipboard),
+            ("Export workflow to file", self.to_file)
         ]
 
         # add Send to script editor menu in case it's installed
@@ -96,8 +97,30 @@ class Assistant(QWidget):
             pass
 
         self.setLayout(QVBoxLayout())
-        self.layout().addWidget(self.seach_field)
+        search_and_help = QWidget()
+        search_and_help.setLayout(QHBoxLayout())
+        from ._button_grid import _get_icon
+        help = QLabel("?")
+        help.setToolTip(
+            '<html>'
+            'Use the search field on the left to enter a term describing the function you would like to apply to your image.\n'
+            'Searching will limit the number of shown categories and listed operations.\n'
+            '<br><br>The icons in the buttons below denote the processed image types:\n'
+            '<br><img src="' + _get_icon("intensity_image") + '" width="24" heigth="24"> In <b>intensity images</b> the pixel value represents a measurement, e.g. of collected light during acquisition in a microscope.\n'
+            '<br><img src="' + _get_icon("binary_image") + '" width="24" heigth="24"> In <b>binary images</b> pixels with value 0 mean there is no object present. All other pixels (typically value 1) represent any object.\n'
+            '<br><img src="' + _get_icon("label_image") + '" width="24" heigth="24"> In <b>label images</b> the integer pixel intensity corresponds to the object identity. E.g. all pixels of object 2 have value 2.\n'
+            '<br><img src="' + _get_icon("parametric_image") + '" width="24" heigth="24"> In <b>parametric images</b> the pixel value represents an object measurement. All pixels of an object can for example contain the same value, e.g. the objects circularity or area.\n'
+            '<br><img src="' + _get_icon("mesh_image") + '" width="24" heigth="24"> In <b>mesh images</b> we can visualize connectivity between objects and distances as intensity along lines.\n'
+            '<br><img src="' + _get_icon("any_image") + '" width="24" heigth="24"> This icon means one can use <b>any kind of image</b> for this operation.'
+            '</html>'
+        )
+        help.setMaximumWidth(20)
+        search_and_help.layout().addWidget(self.seach_field)
+        search_and_help.layout().addWidget(help)
+
+        self.layout().addWidget(search_and_help)
         self.layout().addWidget(icon_grid)
+
         self.layout().setContentsMargins(5, 5, 5, 5)
         self.setMinimumWidth(345)
 
@@ -235,7 +258,9 @@ class Assistant(QWidget):
                     inputs.append(self._id_to_name(op_id, name_dict))
                 else:
                     args.append(w.value)
-            op = getattr(cle, getattr(mgui, OP_NAME_PARAM).value)
+            from .._categories import find_function
+            op = find_function(getattr(mgui, OP_NAME_PARAM).value)
+            #getattr(cle, getattr(mgui, OP_NAME_PARAM).value)
 
             # shorten args by eliminating not-used ones
             if op:
@@ -266,3 +291,13 @@ class Assistant(QWidget):
         import napari_script_editor
         editor = napari_script_editor.ScriptEditor.get_script_editor_from_viewer(self._viewer)
         editor.set_code(Pipeline.from_assistant(self).to_napari_python())
+
+    def to_file(self, filename=None):
+        from napari_workflows import WorkflowManager, _io_yaml_v1
+
+        if not filename:
+            filename, _ = QFileDialog.getSaveFileName(self, "Export workflow ...", ".", "*.yaml")
+
+        # get the workflow, should one be installed
+        workflow_manager = WorkflowManager.install(self._viewer)
+        _io_yaml_v1.save_workflow(filename, workflow_manager.workflow)
